{
    "$graph": [
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/scidap:v0.0.3"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "File",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#custom-bash.cwl/input_file"
                },
                {
                    "type": [
                        "null",
                        "string",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#custom-bash.cwl/param"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "cat \"$0\" | grep \"$1\" | sed \"s/$1//g\"  > `basename $0`\n",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#custom-bash.cwl/script"
                }
            ],
            "baseCommand": [
                "bash",
                "-c"
            ],
            "doc": "Tool to run custom script set as `script` input with arguments from `param`.\nDefault script runs sed command over the input file and exports results to the file with the same name as input's basename\n",
            "id": "#custom-bash.cwl",
            "http://schema.org/name": "custom-bash",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/custom-bash.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:michael.kotliar@cchmc.org",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "id": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Custom bash script runner",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*"
                    },
                    "id": "#custom-bash.cwl/output_file"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "var default_output_filename = function() { if (inputs.output_filename == \"\"){ var root = inputs.segment_file.basename.split('.').slice(0,-1).join('.'); return (root == \"\")?inputs.segment_file.basename+\".tsv\":root+\".tsv\"; } else { return inputs.output_filename; } };"
                    ]
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/gat:v0.0.1"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 6,
                        "prefix": "-a"
                    },
                    "doc": "BED file (strictly 3 columns) with sets of intervals that are used for testing association of segment_file\n",
                    "id": "#gat-run.cwl/annotation_file"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "name": "#gat-run.cwl/counter/counter",
                            "symbols": [
                                "#gat-run.cwl/counter/counter/nucleotide-overlap",
                                "#gat-run.cwl/counter/counter/nucleotide-density",
                                "#gat-run.cwl/counter/counter/segment-overlap",
                                "#gat-run.cwl/counter/counter/annotation-overlap",
                                "#gat-run.cwl/counter/counter/segment-midoverlap",
                                "#gat-run.cwl/counter/counter/annotation-midoverlap"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "position": 10,
                        "prefix": "-c"
                    },
                    "doc": "Set the measure of association that is tested.\nDefault: nucleotide-overlap\n",
                    "id": "#gat-run.cwl/counter"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 9,
                        "prefix": "-n"
                    },
                    "doc": "Number of iterations\n",
                    "id": "#gat-run.cwl/iterations"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 8,
                        "valueFrom": "$(default_output_filename())",
                        "prefix": "-S"
                    },
                    "default": "",
                    "doc": "Output report file name\n",
                    "id": "#gat-run.cwl/output_filename"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 12,
                        "prefix": "--random-seed=",
                        "separate": false
                    },
                    "doc": "Random seed to initialize random number generator with\n",
                    "id": "#gat-run.cwl/seed"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 5,
                        "prefix": "-s"
                    },
                    "doc": "BED file (strictly 3 columns) with sets of intervals whose association is tested with annotation_file\n",
                    "id": "#gat-run.cwl/segment_file"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 11,
                        "prefix": "-t"
                    },
                    "doc": "Threads number\n",
                    "id": "#gat-run.cwl/threads"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 7,
                        "prefix": "-w"
                    },
                    "doc": "BED file (strictly 3 columns) with genomic regions accessible for simulation\n",
                    "id": "#gat-run.cwl/workspace_file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(default_output_filename())"
                    },
                    "doc": "Report file\n",
                    "id": "#gat-run.cwl/report_file"
                },
                {
                    "type": "File",
                    "id": "#gat-run.cwl/stderr_log",
                    "outputBinding": {
                        "glob": "gat_stderr.log"
                    }
                },
                {
                    "type": "File",
                    "id": "#gat-run.cwl/stdout_log",
                    "outputBinding": {
                        "glob": "gat_stdout.log"
                    }
                }
            ],
            "baseCommand": [
                "gat-run.py",
                "--ignore-segment-tracks"
            ],
            "stdout": "gat_stdout.log",
            "stderr": "gat_stderr.log",
            "doc": "A common question in genomic analysis is whether two sets of genomic intervals overlap significantly.\nThis question arises, for example, in the interpretation of ChIP-Seq or RNA-Seq data. The Genomic\nAssociation Tester (GAT) is a tool for computing the significance of overlap between multiple sets of\ngenomic intervals. GAT estimates significance based on simulation.\n\nGat implemements a sampling algorithm. Given a chromosome (workspace) and segments of interest, for\nexample from a ChIP-Seq experiment, gat creates randomized version of the segments of interest falling\ninto the workspace. These sampled segments are then compared to existing genomic annotations.\n\nNote:\n--ignore-segment-tracks parameter is hardcoded\n",
            "id": "#gat-run.cwl",
            "http://schema.org/name": "gat-run",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/gat-run.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Usage\n-----\n\nExample::\n\n  python gat-run.py\n      --segment-file=segments.bed.gz\n      --workspace-file=workspace.bed.gz\n      --annotation-file=annotations_architecture.bed.gz\n\nType::\n\n  python gat-run.py --help\n\nfor command line help.\n\nDocumentation\n-------------\n\nCode\n----\n\n\n\nOptions:\n  --version             show program's version number and exit\n  -h, --help            show this help message and exit\n\n  Input options:\n    -a ANNOTATION_FILES, --annotation-bed-file=ANNOTATION_FILES, --annotations=ANNOTATION_FILES, --annotation-file=ANNOTATION_FILES\n                        filename with annotations [default=[]].\n    -s SEGMENT_FILES, --segment-bed-file=SEGMENT_FILES, --segments=SEGMENT_FILES, --segment-file=SEGMENT_FILES\n                        filename with segments. Also accepts a glob in\n                        parentheses [default=[]].\n    -w WORKSPACE_FILES, --workspace-bed-file=WORKSPACE_FILES, --workspace=WORKSPACE_FILES, --workspace-file=WORKSPACE_FILES\n                        filename with workspace segments. Also accepts a glob\n                        in parentheses [default=[]].\n    -i ISOCHORE_FILES, --isochore-bed-file=ISOCHORE_FILES, --isochores=ISOCHORE_FILES, --isochore-file=ISOCHORE_FILES\n                        filename with isochore segments. Also accepts a glob\n                        in parentheses [default=none].\n    -l SAMPLE_FILES, --sample-file=SAMPLE_FILES\n                        filename with sample files. Start processing from\n                        samples [default=[]].\n    --input-counts-file=INPUT_FILENAME_COUNTS\n                        start processing from counts - no segments required\n                        [default=none].\n    --input-results-file=INPUT_FILENAME_RESULTS\n                        start processing from results - no segments required\n                        [default=none].\n    --ignore-segment-tracks\n                        ignore segment tracks - all segments belong to one\n                        track and called 'merged' [default=True]\n    --with-segment-tracks\n                        the segments data file is arranged in tracks.\n                        [default=True]\n    --enable-split-tracks\n                        permit the same track to be in multiple files\n                        [default=False]\n    --overlapping-annotations\n                        the annotations within a track are overlapping and\n                        should not be merged. This is useful for working with\n                        short-read data. [default=default]\n    --annotations-label=ANNOTATIONS_LABEL\n                        ignore tracks in annotations and instead set them to\n                        label [default=default]\n    --annotations-to-points=ANNOTATIONS_TO_POINTS\n                        convert annotations from segments to positions.\n                        Available methods are 'midpoint', 'start' or 'end'.\n                        [default=default]\n\n  Output options:\n    -o OUTPUT_ORDER, --order=OUTPUT_ORDER\n                        order results in output by fold, track, etc.\n                        [default=fold].\n    --output-tables-pattern=OUTPUT_TABLES_PATTERN\n                        output pattern for result tables. Used if there are\n                        multiple counters used [default=%s.tsv.gz].\n    --output-counts-pattern=OUTPUT_COUNTS_PATTERN\n                        output pattern for counts [default=none].\n    --output-plots-pattern=OUTPUT_PLOTS_PATTERN\n                        output pattern for plots [default=none]\n    --output-samples-pattern=OUTPUT_SAMPLES_PATTERN\n                        output pattern for samples. Samples are stored in bed\n                        format, one for  each segment [default=none]\n    --output-stats=OUTPUT_STATS\n                        output overlap summary stats [default=[]].\n    --output-bed=OUTPUT_BED\n                        output bed files [default=[]].\n    --descriptions=INPUT_FILENAME_DESCRIPTIONS\n                        filename mapping annotation terms to descriptions. if\n                        given, the output table will contain additional\n                        columns [default=none]\n\n  Sampling algorithm options:\n    -c COUNTERS, --counter=COUNTERS\n                        quantity to use for estimating enrichment\n                        [default=[]].\n    -m SAMPLER, --sampler=SAMPLER\n                        quantity to test [default=annotator].\n    -n NUM_SAMPLES, --num-samples=NUM_SAMPLES\n                        number of samples to compute [default=1000].\n    --shift-extension=SHIFT_EXTENSION\n                        if the sampling method is 'shift', create a segment of\n                        size # anound the segment to determine the size of the\n                        region for shifthing [default=0].\n    --shift-expansion=SHIFT_EXPANSION\n                        if the sampling method is 'shift', multiply each\n                        segment by # to determine the size of the region for\n                        shifthing [default=2.0].\n    --bucket-size=BUCKET_SIZE\n                        size of a bin for histogram of segment lengths. If 0,\n                        it will be automatically scaled to fit nbuckets\n                        [default=0]\n    --nbuckets=NBUCKETS\n                        number of bins for histogram of segment lengths\n                        [default=100000]\n\n  Statistics options:\n    -p PVALUE_METHOD, --pvalue-method=PVALUE_METHOD\n                        type of pvalue reported [default=empirical].\n    -q QVALUE_METHOD, --qvalue-method=QVALUE_METHOD\n                        method to perform multiple testing correction by\n                        controlling the fdr [default=BH].\n    --qvalue-lambda=QVALUE_LAMBDA\n                        fdr computation: lambda [default=none].\n    --qvalue-pi0-method=QVALUE_PI0_METHOD\n                        fdr computation: method for estimating pi0\n                        [default=smoother].\n    --pseudo-count=PSEUDO_COUNT\n                        pseudo count. The pseudo count is added to both the\n                        observed and expected overlap. Using a pseudo-count\n                        avoids gat reporting fold changes of 0 [default=1.0].\n    --null=NULL         null hypothesis. The default is to test categories for\n                        enrichment/depletion. If a filename with gat output is\n                        given, gat will test for the difference in fold change\n                        between the segments supplied and in the other file\n                        [default=default].\n\n  Processing options:\n    -e CACHE, --cache=CACHE\n                        filename for caching samples [default=none].\n    -t NUM_THREADS, --num-threads=NUM_THREADS\n                        number of threads to use for sampling [default=0]\n    --random-seed=RANDOM_SEED\n                        random seed to initialize number generator with\n                        [none].\n\n  Workspace manipulation (experimental):\n    --conditional=CONDITIONAL\n                        conditional workspace creation\n                        [default=unconditional]*cooccurance* - compute\n                        enrichment only within workspace segments that contain\n                        both segments and annotations, *annotation-centered* -\n                        workspace centered around annotations. See\n                        --conditional-extension,segment-centered - workspace\n                        centered around segments. See --conditional-extension\n    --conditional-extension=CONDITIONAL_EXTENSION\n                        if workspace is created conditional, extend by this\n                        amount (in bp) [default=none].\n    --conditional-expansion=CONDITIONAL_EXPANSION\n                        if workspace is created conditional, expand by this\n                        amount (ratio) [default=none].\n    --restrict-workspace\n                        restrict workspace to those segments that contain both\n                        track and annotations [default=False]\n    --truncate-workspace-to-annotations\n                        truncate workspace with annotations [default=False]\n    --truncate-segments-to-workspace\n                        truncate segments to workspace before sampling\n                        [default=False]\n\n  Script timing options:\n    --timeit=TIMEIT_FILE\n                        store timeing information in file [none].\n    --timeit-name=TIMEIT_NAME\n                        name in timing file for this class of jobs [all].\n    --timeit-header     add header for timing information [none].\n\n  Common options:\n    -v LOGLEVEL, --verbose=LOGLEVEL\n                        loglevel [1]. The higher, the more output.\n    -?                  output short help (command line options only.\n\n  Input/output options:\n    -P OUTPUT_FILENAME_PATTERN, --output-filename-pattern=OUTPUT_FILENAME_PATTERN\n                        OUTPUT filename pattern for various methods [%s].\n    -F, --force-output  force over-writing of existing files.\n    -I FILE, --stdin=FILE\n                        file to read stdin from [default = stdin].\n    -L FILE, --log=FILE\n                        file with logging information [default = stdout].\n    -E FILE, --error=FILE\n                        file with error information [default = stderr].\n    -S FILE, --stdout=FILE\n                        file where output is to go [default = stdout]."
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "label": "Experiment short name/Alias",
                    "sd:preview": {
                        "position": 1
                    },
                    "id": "#main/alias"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3003",
                    "label": "Annotations (headerless TSV/CSV file with at least three columns: chr start end)",
                    "doc": "Headerless TSV/CSV file (at least 3 columns: chr start end) with sets of intervals that are used\nfor testing association of segment_file\n",
                    "id": "#main/annotation_file"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "name": "#main/counter/counter",
                            "symbols": [
                                "#main/counter/counter/nucleotide-overlap",
                                "#main/counter/counter/nucleotide-density",
                                "#main/counter/counter/segment-overlap",
                                "#main/counter/counter/annotation-overlap",
                                "#main/counter/counter/segment-midoverlap",
                                "#main/counter/counter/annotation-midoverlap"
                            ]
                        }
                    ],
                    "default": "nucleotide-overlap",
                    "label": "Set the measure of association to be tested",
                    "doc": "Set the measure of association to be tested\n",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/counter"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 10000,
                    "label": "Number of random permutations",
                    "doc": "Number of random permutations",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/permutations_count"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 12345,
                    "label": "Number of random seed",
                    "doc": "Number of random seed",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/seed"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3003",
                    "label": "Segments of interest (headerless TSV/CSV file with at least three columns: chr start end)",
                    "doc": "Headerless TSV/CSV file (at least 3 columns: chr start end) with sets of intervals whose association\nwill be tested with annotation_file\n",
                    "id": "#main/segment_file"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 4,
                    "label": "Number of threads",
                    "doc": "Number of threads for those steps that support multithreading",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/threads"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3003",
                    "label": "Workspace (headerless TSV/CSV file with at least three columns: chr start end)",
                    "doc": "Headerless TSV/CSV file (at least 3 columns: chr start end) with genomic regions\naccessible for simulation\n",
                    "id": "#main/workspace_file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3475",
                    "label": "Interval overlap statistics report",
                    "doc": "Interval overlap statistics report",
                    "outputSource": "#main/prepare_report_file/output_file",
                    "sd:visualPlugins": [
                        {
                            "syncfusiongrid": {
                                "tab": "Interval overlap statistics",
                                "Title": "Interval overlap statistics"
                            }
                        }
                    ],
                    "id": "#main/gat_report"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2330",
                    "label": "GAT stderr log",
                    "doc": "GAT stderr log",
                    "outputSource": "#main/run_gat/stderr_log",
                    "id": "#main/gat_stderr_log"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2330",
                    "label": "GAT stdout log",
                    "doc": "GAT stdout log",
                    "outputSource": "#main/run_gat/stdout_log",
                    "id": "#main/gat_stdout_log"
                }
            ],
            "steps": [
                {
                    "run": "#custom-bash.cwl",
                    "in": [
                        {
                            "source": "#main/annotation_file",
                            "id": "#main/prepare_annotation_file/input_file"
                        },
                        {
                            "default": "cat \"$0\" | tr -d '\\r' | tr \",\" \"\\t\" | cut -f 1-3 | awk NF | sort -u -k1,1 -k2,2n -k3,3n > `basename $0`\n",
                            "id": "#main/prepare_annotation_file/script"
                        }
                    ],
                    "out": [
                        "#main/prepare_annotation_file/output_file"
                    ],
                    "id": "#main/prepare_annotation_file"
                },
                {
                    "run": "#custom-bash.cwl",
                    "in": [
                        {
                            "source": "#main/run_gat/report_file",
                            "id": "#main/prepare_report_file/input_file"
                        },
                        {
                            "default": "cat \"$0\" | cut -f 3-  > `basename $0`\n",
                            "id": "#main/prepare_report_file/script"
                        }
                    ],
                    "out": [
                        "#main/prepare_report_file/output_file"
                    ],
                    "id": "#main/prepare_report_file"
                },
                {
                    "run": "#custom-bash.cwl",
                    "in": [
                        {
                            "source": "#main/segment_file",
                            "id": "#main/prepare_segment_file/input_file"
                        },
                        {
                            "default": "cat \"$0\" | tr -d '\\r' | tr \",\" \"\\t\" | cut -f 1-3 | awk NF | sort -u -k1,1 -k2,2n -k3,3n > `basename $0`\n",
                            "id": "#main/prepare_segment_file/script"
                        }
                    ],
                    "out": [
                        "#main/prepare_segment_file/output_file"
                    ],
                    "id": "#main/prepare_segment_file"
                },
                {
                    "run": "#custom-bash.cwl",
                    "in": [
                        {
                            "source": "#main/workspace_file",
                            "id": "#main/prepare_workspace_file/input_file"
                        },
                        {
                            "default": "cat \"$0\" | tr -d '\\r' | tr \",\" \"\\t\" | cut -f 1-3 | awk NF | sort -u -k1,1 -k2,2n -k3,3n > `basename $0`\n",
                            "id": "#main/prepare_workspace_file/script"
                        }
                    ],
                    "out": [
                        "#main/prepare_workspace_file/output_file"
                    ],
                    "id": "#main/prepare_workspace_file"
                },
                {
                    "run": "#gat-run.cwl",
                    "in": [
                        {
                            "source": "#main/prepare_annotation_file/output_file",
                            "id": "#main/run_gat/annotation_file"
                        },
                        {
                            "source": "#main/counter",
                            "id": "#main/run_gat/counter"
                        },
                        {
                            "source": "#main/permutations_count",
                            "id": "#main/run_gat/iterations"
                        },
                        {
                            "source": "#main/seed",
                            "id": "#main/run_gat/seed"
                        },
                        {
                            "source": "#main/prepare_segment_file/output_file",
                            "id": "#main/run_gat/segment_file"
                        },
                        {
                            "source": "#main/threads",
                            "id": "#main/run_gat/threads"
                        },
                        {
                            "source": "#main/prepare_workspace_file/output_file",
                            "id": "#main/run_gat/workspace_file"
                        }
                    ],
                    "out": [
                        "#main/run_gat/report_file",
                        "#main/run_gat/stdout_log",
                        "#main/run_gat/stderr_log"
                    ],
                    "id": "#main/run_gat"
                }
            ],
            "label": "GAT - Genomic Association Tester",
            "doc": "GAT: Genomic Association Tester\n==============================================\n\nA common question in genomic analysis is whether two sets of genomic intervals overlap significantly.\nThis question arises, for example, in the interpretation of ChIP-Seq or RNA-Seq data. The Genomic\nAssociation Tester (GAT) is a tool for computing the significance of overlap between multiple sets of\ngenomic intervals. GAT estimates significance based on simulation.\n\nGat implemements a sampling algorithm. Given a chromosome (workspace) and segments of interest, for\nexample from a ChIP-Seq experiment, gat creates randomized version of the segments of interest falling\ninto the workspace. These sampled segments are then compared to existing genomic annotations.\n\nThe sampling method is conceptually simple. Randomized samples of the segments of interest are created\nin a two-step procedure. Firstly, a segment size is selected from to same size distribution as the\noriginal segments of interest. Secondly, a random position is assigned to the segment. The sampling stops\nwhen exactly the same number of nucleotides have been sampled. To improve the speed of sampling, segment\noverlap is not resolved until the very end of the sampling procedure. Conflicts are then resolved by\nrandomly removing and re-sampling segments until a covering set has been achieved. Because the size of\nrandomized segments is derived from the observed segment size distribution of the segments of interest,\nthe actual segment sizes in the sampled segments are usually not exactly identical to the ones in the\nsegments of interest. This is in contrast to a sampling method that permutes segment positions within\nthe workspace.",
            "id": "#main",
            "http://schema.org/name": "GAT - Genomic Association Tester",
            "http://schema.org/alternateName": "GAT - Genomic Association Tester",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/datirium/workflows/master/workflows/gat-run.cwl",
            "http://schema.org/codeRepository": "https://github.com/datirium/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ]
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "http://schema.org/version/9.0/schemaorg-current-http.rdf",
        "http://schema.org/docs/schema_org_rdfa.html"
    ],
    "$namespaces": {
        "s": "http://schema.org/"
    }
}
